Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(116)

Unified Diff: net/base/net_error_list.h

Issue 3976004: Adds a new error for cases where a firewall may be the issue. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 10 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | net/ftp/ftp_network_transaction.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/base/net_error_list.h
===================================================================
--- net/base/net_error_list.h (revision 63512)
+++ net/base/net_error_list.h (working copy)
@@ -50,7 +50,7 @@
// invalid assumption.
NET_ERROR(UNEXPECTED, -9)
// Permission to access a resource was denied.
NET_ERROR(ACCESS_DENIED, -10)
// The operation failed because of unimplemented functionality.
@@ -66,7 +66,7 @@
// from the expectation.
NET_ERROR(UPLOAD_FILE_CHANGED, -14)
-// The socket is not connected
+// The socket is not connected.
NET_ERROR(SOCKET_NOT_CONNECTED, -15)
// A connection was closed (corresponding to a TCP FIN).
@@ -208,6 +208,11 @@
// An error occurred when trying to do a name resolution (DNS).
NET_ERROR(NAME_RESOLUTION_FAILED, -137)
+// Permission to access the network was denied. This is used to distinguish
+// access denied errors that were most likely caused by a firewall.
+// See also ERR_ACCESS_DENIED.
+NET_ERROR(NETWORK_ACCESS_DENIED, -138)
+
// Certificate error codes
//
// The values of certificate error codes must be consecutive.
@@ -50,7 +50,7 @@
// invalid assumption.
NET_ERROR(UNEXPECTED, -9)
-// Permission to access a resource was denied.
+// Permission to access a resource, other than the network, was denied.
NET_ERROR(ACCESS_DENIED, -10)
// The operation failed because of unimplemented functionality.
« no previous file with comments | « no previous file | net/ftp/ftp_network_transaction.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698